@@ -11,8 +11,7 @@
 #elif defined (MEEGO_EDITION_HARMATTAN)
 #include <QTimer>
 #include <qmsystem2/qmdisplaystate.h>
-#else
-#include <qmobilityglobal.h>
+#elif !defined (Q_WS_SIMULATOR)
 #include <QSystemScreenSaver>
 
 QTM_USE_NAMESPACE
@@ -36,7 +35,7 @@ private:
 #ifdef MEEGO_EDITION_HARMATTAN
     MeeGo::QmDisplayState m_displayState;
     QTimer m_timer;
-#else
+#elif !defined (Q_WS_SIMULATOR)
     QSystemScreenSaver m_screenSaver;
 #endif
 #endif
