@@ -17,6 +17,9 @@ class Notifications;
 class TransferManager;
 class ClipboardMonitor;
 class QNetworkAccessManager;
+#ifdef GRABBER_PLUGIN
+class PluginManager;
+#endif
 #ifndef QML_USER_INTERFACE
 class ThumbnailCache;
 #ifdef Q_WS_MAEMO_5
@@ -49,6 +52,9 @@ private:
     Vimeo *m_vimeo;
     Sharing *m_sharing;
     UrlGrabber *m_grabber;
+#ifdef GRABBER_PLUGIN
+    PluginManager *m_pluginManager;
+#endif
     Notifications *m_notifications;
     TransferManager *m_transferManager;
     ClipboardMonitor *m_monitor;
