@@ -237,7 +237,15 @@ QMap<int, QUrl> UrlGrabber::getYouTubeVideoUrlMap(QString page, QScriptValue dec
             QStringList splitPart = part.split("url=");
 
             if (!splitPart.isEmpty()) {
-                QUrl url(splitPart.last());
+                QString urlString = splitPart.last();
+                QStringList params = urlString.mid(urlString.indexOf('?') + 1).split('&', QString::SkipEmptyParts);
+                params.removeDuplicates();
+
+                QUrl url(urlString.left(urlString.indexOf('?')));
+
+                foreach (QString param, params) {
+                    url.addQueryItem(param.section('=', 0, 0), param.section('=', -1));
+                }
 
                 if (!url.hasQueryItem("signature")) {
                     url.addQueryItem("signature", splitPart.first().section("signature=", 1, 1).section('&', 0, 0));
@@ -254,7 +262,15 @@ QMap<int, QUrl> UrlGrabber::getYouTubeVideoUrlMap(QString page, QScriptValue dec
             QStringList splitPart = part.split("url=");
 
             if (!splitPart.isEmpty()) {
-                QUrl url(splitPart.last());
+                QString urlString = splitPart.last();
+                QStringList params = urlString.mid(urlString.indexOf('?') + 1).split('&', QString::SkipEmptyParts);
+                params.removeDuplicates();
+
+                QUrl url(urlString.left(urlString.indexOf('?')));
+
+                foreach (QString param, params) {
+                    url.addQueryItem(param.section('=', 0, 0), param.section('=', -1));
+                }
 
                 if (!url.hasQueryItem("signature")) {
                     url.addQueryItem("signature", splitPart.first().section("signature=", 1, 1).section('&', 0, 0));
@@ -317,7 +333,7 @@ void UrlGrabber::checkYouTubeVideoInfoPage() {
         }
         else {
             qDebug() << "YouTube video info OK. Parsing the page";
-            response.replace("%2C" + separator, "," + separator);
+            response.replace(QRegExp("%2C(\\w+%3D1%26|)" + separator), "," + separator);
             this->parseYouTubeVideoPage(QScriptValue(), response);
         }
     }
