@@ -21,6 +21,7 @@ VimeoUserAlbumListModel::VimeoUserAlbumListModel(QObject *parent) :
     roles[ThumbnailRole] = "thumbnail";
 #endif
     roles[ThumbnailUrlRole] = "thumbnailUrl";
+    roles[LargeThumbnailUrlRole] = "largeThumbnailUrl";
     roles[DescriptionRole] = "description";
     this->setRoleNames(roles);
 #ifndef QML_USER_INTERFACE
@@ -84,6 +85,8 @@ QVariant VimeoUserAlbumListModel::data(const QModelIndex &index, int role) const
 #endif
     case ThumbnailUrlRole:
         return Vimeo::instance()->albums()->at(index.row()).data()->thumbnailUrl();
+    case LargeThumbnailUrlRole:
+        return Vimeo::instance()->albums()->at(index.row()).data()->largeThumbnailUrl();
     case DescriptionRole:
         return Vimeo::instance()->albums()->at(index.row()).data()->description();
     default:
