@@ -22,6 +22,7 @@
 #include <QLabel>
 #include <QScrollArea>
 #include <QGridLayout>
+#include <QMaemo5Style>
 
 DailymotionVideoDescriptionTab::DailymotionVideoDescriptionTab(QSharedPointer<VideoItem> video, QWidget *parent) :
     AbstractTab(parent),
@@ -38,8 +39,8 @@ DailymotionVideoDescriptionTab::DailymotionVideoDescriptionTab(QSharedPointer<Vi
     m_ratingIndicator(new RatingIndicator(m_video.data()->rating(), m_video.data()->ratingCount(), this)),
     m_titleLabel(new QLabel(m_video.data()->title(), this)),
     m_dateLabel(new QLabel(QString("%1 - %2").arg(m_video.data()->date()).arg(m_video.data()->artist()), this)),
-    m_viewsLabel(new QLabel(QString("%1   <font color='#4d4d4d'>%2</font>").arg(tr("Views")).arg(m_video.data()->viewCount()), this)),
-    m_descriptionLabel(new QLabel(QString("Description<br><font color='#4d4d4d'>%1</font>").arg(m_video.data()->description().isEmpty() ? tr("No description") : m_video.data()->description()), this)),
+    m_viewsLabel(new QLabel(QString("%1   <font color='%2'>%3</font>").arg(tr("Views")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->viewCount()), this)),
+    m_descriptionLabel(new QLabel(QString("%1<br><font color='%2'>%3</font>").arg(tr("Description")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->description().isEmpty() ? tr("No description") : m_video.data()->description()), this)),
     m_tagsLabel(new QLabel(this->tagsToString(m_video.data()->tags()), this)),
     m_scrollArea(new QScrollArea(this)),
     m_grid(new QGridLayout(this))
@@ -135,7 +136,7 @@ QString DailymotionVideoDescriptionTab::tagsToString(QStringList tags) {
     QString tagString("Tags<br>");
 
     if (tags.isEmpty()) {
-        tagString.append(QString("<p style='color:#4d4d4d;'>%1</p>").arg(tr("No tags")));
+        tagString.append(QString("<p style='color:%1;'>%2</p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No tags")));
     }
     else {
         while (!tags.isEmpty()) {
