@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include "../base/videoitem.h"
 
-class Session;
 class YouTubeUploadCategorySelector;
 class YouTubePermissionSelector;
 class QLineEdit;
@@ -20,7 +19,7 @@ class YouTubeMetadataDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit YouTubeMetadataDialog(Session *session, QSharedPointer<VideoItem> video, QWidget *parent = 0);
+    explicit YouTubeMetadataDialog(QSharedPointer<VideoItem> video, QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -33,7 +32,6 @@ private slots:
     void submitMetadata();
     
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     QLineEdit *m_titleEdit;
     QTextEdit *m_descriptionEdit;
