@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/useritem.h"
 
-class Session;
 class SeparatorLabel;
 class AvatarLabel;
 class QLabel;
@@ -18,7 +17,7 @@ class YouTubeProfileTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit YouTubeProfileTab(Session *session, const QString &userId, QWidget *parent = 0);
+    explicit YouTubeProfileTab(const QString &userId, QWidget *parent = 0);
     
 private:
     void setLandscapeLayout();
@@ -36,7 +35,6 @@ private slots:
     void showWatchHistory();
     
 private:
-    Session *m_session;
     QSharedPointer<UserItem> m_user;
     AvatarLabel *m_avatar;
     QLabel *m_channelLabel;
