@@ -5,7 +5,6 @@
 #include "../base/videoitem.h"
 #include "../base/commentitem.h"
 
-class Session;
 class YouTubeCommentListModel;
 class ListView;
 class QMenu;
@@ -19,7 +18,7 @@ class YouTubeVideoCommentsTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit YouTubeVideoCommentsTab(Session *session, QSharedPointer<VideoItem> video, QWidget *parent);
+    explicit YouTubeVideoCommentsTab(QSharedPointer<VideoItem> video, QWidget *parent);
 
 private:
     void setLandscapeLayout();
@@ -34,7 +33,6 @@ private slots:
     void showUserChannel(const QModelIndex &index);
     
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     YouTubeCommentListModel *m_model;
     ListView *m_listView;
