@@ -18,6 +18,7 @@
 #include <QGridLayout>
 #include <QMenu>
 #include <QTimer>
+#include <QMaemo5Style>
 
 YouTubeVideoListTab::YouTubeVideoListTab(QWidget *parent) :
     AbstractTab(parent),
@@ -40,7 +41,7 @@ YouTubeVideoListTab::YouTubeVideoListTab(QWidget *parent) :
     m_addToQueueContextAction(m_contextMenu->addAction(tr("Add to playback queue"), this, SLOT(queueVideo()))),
     m_videoDownloadContextAction(m_contextMenu->addAction(tr("Download"), this, SLOT(addVideoDownload()))),
     m_audioDownloadContextAction(m_contextMenu->addAction(tr("Download (audio)"), this, SLOT(addAudioDownload()))),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No videos found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No videos found")), this)),
     m_grid(new QGridLayout(this))
 {
     this->addAction(m_deleteFromUploadsAction);
